@@ -308,15 +308,20 @@ def batch():
     return to_dc_format(df)
 
 
-@pytest.fixture(scope="session", params=[1, 10, 100, 1000])
-def load_data(connector, batch, good_object_id, mapping_object, _replace, request, batch_size):
-    total_batches = (request.param * GB) / batch_size
+@pytest.fixture(scope="session", params=('size', [1, 10, 100, 1000]))
+def load_data(connector, batch, good_object_id, mapping_object, _replace, size, batch_size):
+    total_batches = (size * GB) / batch_size
     batch_number = 1
+    rows_loaded = 0
     connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
 
     while batch_number <= total_batches:
+        rows_loaded += len(batch)
+        print(f"Loaded {rows_loaded} rows out of {total_batches * len(batch)}")
         batch_number += 1
         connector.load_data(batch, good_object_id, mapping_object, _replace, batch_number, total_batches)
+
+    print(f"Loaded {rows_loaded} rows out of {total_batches * len(batch)}.\nTotal size uploaded: {size * GB}")
     return True
 
 
