@@ -543,5 +543,5 @@ class TestLoadData:
         assert load_data
         end = time.time()
         elapsed_time = end - start
-        print(elapsed_time)
+        print(f"Time elapsed to load {load_data.param} GB: " + str(elapsed_time))
         assert elapsed_time < 10 * 60
